Tensor

Struct Tensor 

pub struct Tensor<const N: usize, const R: usize, I, S> { /* private fields */ }
Basic tensor object. Depends on dimension (N), rank (R), Symmetries (I) and storage array (S).

Implementations

Source

impl<const N: usize, const R: usize, I, S> Tensor<N, R, I, S>

pub fn dim() -> usize

Retrieves the dimension of the tensor.

pub fn rank() -> usize

Retrieves the rank of the tensor.

Source

impl<const N: usize, const R: usize, I: TensorIndex<N, R>, S: TensorStorageOwned + Default> Tensor<N, R, I, S>

pub fn new() -> Self

Constructs a new tensor with undefined internal values.

pub fn from_fn(f: impl Fn([usize; R]) -> f64) -> Self

Constructs a new tensor by repeatidly calling a function on each index.

pub fn splat(v: f64) -> Self

Constructs a tensor with all components initialized to v.

pub fn zeros() -> Self

Constructs a tensor initialized with all components inititialized to zero.

pub fn from_eq<const C: usize>( f: impl Fn([usize; R], [usize; C]) -> f64, ) -> Self

Constructs a tensor from a tensorial expression.

Source

impl<const N: usize, const R: usize, I: TensorIndex<N, R>, S: TensorStorageMut> Tensor<N, R, I, S>

pub fn fill(&mut self, v: f64)

Sets all free components of the tensor to v.

pub fn fill_from_fn(&mut self, f: impl Fn([usize; R]) -> f64)

Sets values of components of the tensor be invoking the given function.

Source

impl<const N: usize, const R: usize, I: TensorIndex<N, R>, S: TensorStorageRef> Tensor<N, R, I, S>

pub fn get(&self, index: [usize; R]) -> &f64

Retrieves the component at the given index of the tensor.

Source

impl<const N: usize, const R: usize, I: TensorIndex<N, R>, S: TensorStorageMut> Tensor<N, R, I, S>

pub fn get_mut(&mut self, index: [usize; R]) -> &mut f64

Retrieves a mutable reference to the degree of freedom corresponding to the given index of the tensor.